@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -132,6 +132,7 @@ void gcpElectronTool::OnDrag ()
 {
 	if (!m_pItem)
 		return;
+	int old_pos = m_Pos;
 	m_x -= m_x0;
 	m_y -= m_y0;
 	m_dDist = sqrt (square (m_x) + square (m_y));
@@ -253,7 +254,8 @@ void gcpElectronTool::OnDrag ()
 								NULL);
 			}
 			m_bChanged = true;
-		}
+		} else
+			m_Pos = old_pos;
 	}
 	char tmp[32];
 	snprintf(tmp, sizeof(tmp) - 1, _("Orientation: %g"), m_dAngle * 180. / M_PI);
